@@ -28,13 +28,13 @@ series0 <- function(m, series, reeval = TRUE, data.frame = FALSE){
     return(data.frame(time = time, df0))
   }
   
-  z <- try(as_xts_xtsimp(z0))
+  z <- try(as_xts_xtsimp(z0), silent = TRUE)
 
   if (inherits(z, "try-error")){
-    z <- try(xts::xts(z0, order.by = as.Date(paste(seq(NROW(z0)), "1", "1", sep = "-"))))
+    z <- try(xts::xts(z0, order.by = as.Date(paste(seq(NROW(z0)), "1", "1", sep = "-"))), silent = TRUE)
   }
 
-   if (inherits(z, "try-error")){
+  if (inherits(z, "try-error")){
     stop('xts conversion problem with series: ', series)
   }
 
